@@ -14,7 +14,7 @@ trim <- function (x) gsub("^\\s+|\\s+$", "", x)
 #'spm_time_dep : a function that estimates parameters from the model with time-dependent coefficients.
 #'@param x : input data table.
 #'@param start : a list of starting parameters, default: list(a=-0.5, f1=80, Q=2e-8, f=80, b=5, mu0=1e-5),
-#'@param f : a list of formulas that define age (time) - dependency. Default: list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0")
+#'@param frm : a list of formulas that define age (time) - dependency. Default: list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0")
 #'@param stopifbound Estimation stops if at least one parameter achieves lower or upper boundaries.
 #'@param algorithm An optimization algorithm used, can be one of those: NLOPT_LN_NEWUOA,NLOPT_LN_NEWUOA_BOUND or NLOPT_LN_NELDERMEAD. Default: NLOPT_LN_NELDERMEAD
 #'@param lb Lower bound of parameters under estimation.
@@ -37,7 +37,7 @@ trim <- function (x) gsub("^\\s+|\\s+$", "", x)
 #'
 spm_time_dep <- function(x, 
                          start=list(a=-0.05, f1=80, Q=2e-8, f=80, b=5, mu0=1e-3),
-                         f=list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0"), 
+                         frm=list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0"), 
                          stopifbound=FALSE, 
                          algorithm="NLOPT_LN_NELDERMEAD",
                          lb=NULL, ub=NULL,
@@ -416,7 +416,7 @@ spm_time_dep <- function(x,
   }
   #---------------------End of optimize---------------------------#
   
-  formulas <- f
+  formulas <- frm
   data <- as.matrix(x)
   data <- data[, 2:dim(data)[2]]
   formulas.work = list(at="a", f1t="f1", Qt="Q", ft="f", bt="b", mu0t="mu0")
